#
# spec file for package bazel-rules-go
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define src_install_dir /usr/src/%{name}

Name:           bazel-rules-go
Version:        0.20.3
Release:        bp154.1.20
Summary:        Go rules for Bazel
License:        Apache-2.0
Group:          Development/Tools/Building
Url:            https://github.com/bazelbuild/rules_go
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
BuildRequires:  fdupes

%description
Bazel rules which support building software written in Go, specifically:
- building libraries
- building binaries
- executing tests
- vendoring
- cgo builds
- cross compilation
- auto generating Bazel BUILD files
- build-time code analysis via nogo

%package source
Summary:        Source code of bazel-rules-go
Group:          Development/Sources
BuildArch:      noarch

%description source
Bazel rules which support building software written in Go, specifically:
- building libraries
- building binaries
- executing tests
- vendoring
- cgo builds
- cross compilation
- auto generating Bazel BUILD files
- build-time code analysis via nogo

This package contains source code of bazel-rules-go.

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{src_install_dir}
cp -R * %{buildroot}%{src_install_dir}
# Fix hidden-dile-or-dir warning.
find %{buildroot}%{src_install_dir} -name ".*" -exec rm -rf "{}" +
# Fix env-script-interpreter error.
find %{buildroot}%{src_install_dir} -type f -name "*.py" -exec sed -i 's|#!/usr/bin/env python|#!/usr/bin/python|' "{}" +

%fdupes %{buildroot}%{src_install_dir}

%files source
%license LICENSE.txt
%doc README.rst
%{src_install_dir}

%changelog
* Mon Jan 13 2020 Michał Rostecki <mrostecki@opensuse.org>
- Remove patch which is not needed anymore:
  * 0001-bazel-Use-http_archive-instead-of-git_repository.patch
* Mon Jan 13 2020 mrostecki@opensuse.org
- Update to version 0.20.3:
  * Support go1.13.5, 1.12.14 (#2308)
  * tests/legacy/trans_dep_error: delete test (#2303)
  * Migrate reproducibility test to go_bazel_test (#2299)
  * Clear GOPATH in go_context (#2291)
  * nogo: defer wg.Done() (#2300)
  * Remove //tests/legacy/cgo_library_root_dir (#2297)
  * Migrate legacy test to //tests/core/go_test:test_filter_test (#2298)
  * Migrate legacy tests to //tests/core/go_download_sdk (a go_bazel_test) (#2296)
  * Use bash from the environment instead of absolute path (#2295)
  * Migrate //tests/core/race to go_bazel_test (#2293)
  * tests/core/nogo: migrate to go_bazel_test (#2289)
  * tests/core/coverage: migrate to go_bazel_test (#2288)
  * go/tools/bazel_testing: support location args without external prefix (#2287)
  * Add SetUp method to Args for go_bazel_test (#2282)
  * Add support for dirs in txtar expander (#2280)
  * Conditionally include Bazel testing library only if needed (#2279)
  * go_compat_repo: alias constraint values and settings to bazel_tools or platforms (#2275)
  * skip directory matching in FindBinary (#2274)
  * go_bazel_test: add test to ensure data and args keep working (#2248)
  * delete unused cgoarc flag from compilepkg builder (#2264)
  * Set RULES_GO_VERSION to 0.20.3
  * Support go1.13.4, 1.12.13 (#2269)
  * Set RULES_GO_VERSION to 0.20.2
* Thu Dec 19 2019 Madhu Mohan Nelemane <mmnelemane@suse.com>
- Updated to version 0.20.1
  * updated patch to match 0.20.1 source:
    [ 0001-bazel-Use-http_archive-instead-of-git_repository.patch ]
* Fri Sep 13 2019 Michał Rostecki <mrostecki@opensuse.org>
- Add patch which uses http_archive instead of git_repository in
  Bazel. git_repository makes it impossible to pre-fetch or
  override dependencies:
  * 0001-bazel-Use-http_archive-instead-of-git_repository.patch
* Thu Sep  5 2019 mrostecki@suse.com
- Update to version 0.18.5:
  * Windows: future-proof single_output_test.bzl (#2064)
  * Move cc_configure_features ctx back to v25 (#2063)
  * Bazel compatibility updates (#2062)
  * Depend on @bazel_tools//tools/cpp:toolchain_type in go_context_data (#2060)
  * Fix for Bazel upcoming change incompatible_string_join_requires_strings (#2059)
  * Migrate for Bazel's --incompatible_require_ctx_in_configure_features (#2054)
  * Set RULES_GO_VERSION to 0.18.5
  * Add shallow_since to com_google_protobuf (#2019)
  * Support for go1.12.5 and go1.11.10 (#2050)
  * update pin to bazel toolchains repo (#2038)
  * Make nogo work on Windows (path handling) (#2033)
  * files_equal_test: rewrite as genrule + sh_test (#2035)
  * Set RULES_GO_VERSION to 0.18.4
  * Support new Go releases (#2028)
  * Set RULES_GO_VERSION to 0.18.3
  * Support Go 1.12.2 and 1.11.7 (#2022)
  * Fix warnings from --incompatible_disallow_struct_provider_syntax (#2015)
  * Use -trimpath to make go_tool_binary deterministic. (#2011)
  * Band-aid gRPC cross-compilation for Linux (#2009)
  * go_tool_binary: set GOROOT explicitly (#2008)
  * Fix incompatibility warning in bazel_test (#1978)
  * go_binary: correctly apply x_defs to main package when linking (#2001)
  * Fix gRPC cross-compilation for Android (#1991)
  * Pass ProtoInfo instead of Target to proto_path (#1985)
  * Set RULES_GO_VERSION to 0.18.2
  * Add support for Go 1.12.1 and 1.11.6 (#1994)
  * Set RULES_GO_VERSION to 0.18.1
  * Remove deprecated support for Go 1.9 and go_vet_test (#1977)
  * Set RULES_GO_VERSION to 0.18.0 (#1975)
  * Update dependencies (#1974)
  * Announce Gazelle 0.17.0 [skip ci] (#1969)
  * Announce incompatible protobuf release [skip ci] (#1968)
  * Add shallow_since to git_repository dependencies (#1960)
  * Announce new Go releases [skip ci] (#1965)
  * Support for Go 1.12 (#1963)
  * go_download_sdk: work around bazel bug extracting .tar.gz files (#1949)
  * cgo: don't require cc_library to produce files (#1956)
  * Make googleapis work on FreeBSD. (#1954)
  * Consolidate actions into a single builder binary (#1947)
  * nogo: collect more type information (#1946)
  * nogo: make fact files optional for dependencies (#1941)
  * nogo.rst: doc tweaks (#1938)
  * Update bazel_toolchains to latest release (#1939)
  * go/private/compat: use newest version if native.bazel_version is None (#1936)
  * nogo: register fact types before encoding / decoding (#1934)
  * Add compatibility repository for supporting older Bazel versions (#1933)
  * Announce 0.17.0 release [skip ci] (#1929)
  * Set RULES_GO_VERSION to 0.17.0 (#1927)
  * change import_path_option default value to false (#1923)
  * Move repository definitions from //go:def.bzl to //go:deps.bzl (#1926)
  * Pass all SDK files as inputs to go_info (#1917)
  * Add deps.bzl with compatibility definitions from def.bzl [skip ci] (#1925)
  * Fix `gofast` `go_proto_compiler` dependencies. (#1915)
  * Announce new releases in README.rst [skip ci] (#1920)
  * Support Go 1.11.5 and 1.10.8 (#1919)
  * Update dependencies to latest versions as of 2019-01-15 (#1914)
  * Deprecate go_vet_test and Go 1.9 support (#1901)
  * Stop passing alwayslink=1 with linkmode="c-shared" (#1913)
  * Use cc_binary and cc_import to produce shared libraries (#1889)
  * Add example for go_repository rule (#1906)
  * Update to newer version of Gazelle for testing (#1903)
  * Skip part of //tests/reproducibility:go_default_test in BuildKite (#1902)
  * go/tools/builders/stdlib: set temporary GOCACHE (#1900)
  * go/tools/builders/pack: preserve file extensions (#1899)
  * go/tool/compile: generate symabis for assembly (#1898)
  * nogo: translate 'vet = True' into appropriate deps (#1897)
  * go_proto_library: support multiple proto dependencies (#1890)
  * Add FAQ about modules [skip ci] (#1882)
  * go_download_sdk: workaround bug in ctx.download_and_extract (#1887)
  * Make gofmt available via sdk.tools (#1845)
  * go_proto_library: support proxy proto_library (#1870)
  * Fix Windows & Darwin cross-compilation to Linux when using gRPC (#1876)
  * go_proto_library: support adjusted import prefixes (#1869)
  * Add documentation on configuring C/C++ toolchains [skip ci] (#1868)
  * remove non-existent Finding from nogo sample (#1878)
  * fix README.rst indentation for gazelle (#1874)
  * Announce Gazelle 0.16.0 [skip ci] (#1866)
  * Pure mode when using the goos attribute (#1864)
  * Announce point releases [skip ci] (#1861)
  * Support Go 1.11.4 and 1.10.7 (#1860)
  * Add link to gomock rule (#1855)
  * Ensure nogo is run on libraries compiled with the aspect (#1854)
  * Announce new releases [skip ci] (#1853)
  * Add support for Go 1.11.3 and 1.10.6 (#1852)
  * nogo: pass explicit path to .x output file (#1848)
  * Fix borken handling of 32-bit ARM platform (#1840)
  * Announce point releases [skip ci] (#1838)
  * Don't iterate depsets in objc providers (#1835)
  * Expose proto generated sources via OutputGroup (#1827)
  * Fix for remaining Bazel incompatible changes (#1834)
  * fix sdk download for ppc64le (#1832)
  * Explicitly reexport some symbols, reformat the .bzl files with Buildifier (#1830)
  * Update bazel-toolchains pin (#1833)
  * Update vendored skylib to 0.5.0 (#1831)
  * Add FAQ for vendored gRPC [skip ci] (#1826)
  * Fix mismatching version and hash in gazelle sec (#1823)
  * Add runfiles support for Windows. (#1816)
  * Add @com_github_golang_protobuf//protoc-gen-go/generator:go_default_library_gen (#1818)
  * nogo: support go/analysis fact serialization (#1810)
  * Windows: use filegroup instead of genrule to get .so file from a cc_library (#1813)
  * Announce 0.16.2, 0.15.7, and 0.14.5 [skip ci] (#1809)
  * Update org_golang_x_tools (#1802)
  * Don't compile cgo code with --coverage (#1808)
  * Add support for Go 1.11.2 and 1.10.5 (#1805)
  * Don't analyze bazel_test targets in host workspace (#1804)
  * Allow specifying the `js_wasm` toolchain. (#1797)
  * Better documentation for the embed attribute [skip ci] (#1795)
  * Update bazel_toolchains pin. (#1793)
  * Pass tests if rules_go is an external repository (#1614)
  * Announce release 0.16.1, 0.15.6, 0.14.4 [skip ci] (#1792)
  * Improve nogo documentation (#1779)
  * Move tools/bazel.rc to .bazelrc (#1786)
  * De-duplicate dependencies with the same import path (#1785)
  * Fix execute arguments to use list (#1783)
  * Add go_tool_library targets for analysis passes (#1781)
  * Update org_golang_x_tools dependency (#1773)
  * nogo: write vet.cfg to random temporary configuration file (#1778)
  * Remove spurious newlines from print messages (#1774)
  * Exclude srcs and their runfiles from Go rule runfiles (#1776)
  * Announce rules_go 0.16.0 in README [skip ci] (#1770)
  * Migrate to cc_common for collecting C/C++ paths and options (#1768)
  * Set RULES_GO_VERSION to 0.16.0 (#1769)
  * lcov_merger: workaround for Bazel 0.18.0 coverage (#1767)
  * Use a more unique name for the cover variable (#1764)
  * nogo: rename apply_to and whitelist config fields (#1763)
  * go_download_sdk: allow goos, goarch to be specified explicitly (#1762)
  * nogo is a tool that analyzes the source code of Go programs. (#1759)
  * Use absolute paths to make GoPack work on Windows (#1757)
  * Add compiled archives to compilation_outputs group (#1756)
  * Define the toolchain_type target used by go rules. (#1754)
  * Fix dead reference to reproducible_binary in README [skip ci] (#1753)
* Wed Feb 20 2019 Michał Rostecki <mrostecki@opensuse.org>
- Update to version 0.16.5:
  * nogo is a new framework for running static analysis as part of
    Bazel builds. Developers can write their own analyzers which
    run alongside the compiler on each Go package. Analyzers may
    stop the build when they detect problems.
  * rules_go now uses the new cc_common module to collect C / C++
    flags. This ensures compatibility with future versions of
    Bazel, since the CROSSTOOL-related fields in CcToolchainInfo
    are being removed soon.
  * go_download_sdk now supports goos and goarch attributes. These
    may be useful for remote execution when the execution platform
    is different from the host platform.
  * Cgo now declares internal targets in each supported mode that
    influences the selection of source files and dependencies with
    build constraints.
  * Support for Go 1.11.4 and 1.10.7.
  * Several Bazel compatibility fixes and small bug fixes.
  * Exclude srcs and their runfiles from Go rule runfiles.
  * De-duplicate dependencies with the same import path.
* Tue Jan  8 2019 Michał Rostecki <mrostecki@suse.de>
- Initial version 0.15.0+git.20181003
